Feedforward Closedloop Learning: Member List

Feedforward Closedloop Learning

feedforward_closedloop_learning.Layer Member List

This is the complete list of members for feedforward_closedloop_learning.Layer, including all inherited members.

__init__(self, "int" _nNeurons, "int" _nInputs) | feedforward_closedloop_learning.Layer |
calcOutputs(self) | feedforward_closedloop_learning.Layer |
doLearning(self) | feedforward_closedloop_learning.Layer |
doNormaliseWeights(self) | feedforward_closedloop_learning.Layer |
getError(self, "int" i) | feedforward_closedloop_learning.Layer |
getNeuron(self, "int" index) | feedforward_closedloop_learning.Layer |
getNinputs(self) | feedforward_closedloop_learning.Layer |
getNneurons(self) | feedforward_closedloop_learning.Layer |
getOutput(self, "int" index) | feedforward_closedloop_learning.Layer |
getWeightDistanceFromInitialWeights(self) | feedforward_closedloop_learning.Layer |
initWeights(self, *args) | feedforward_closedloop_learning.Layer |
saveWeightMatrix(self, "char *" filename) | feedforward_closedloop_learning.Layer |
setActivationFunction(self, "Neuron::ActivationFunction" _activationFunction) | feedforward_closedloop_learning.Layer |
setBias(self, "double" _bias) | feedforward_closedloop_learning.Layer |
setConvolution(self, "int" width, "int" height) | feedforward_closedloop_learning.Layer |
setDebugInfo(self, "int" layerIndex) | feedforward_closedloop_learning.Layer |
setDecay(self, "double" _decay) | feedforward_closedloop_learning.Layer |
setError(self, *args) | feedforward_closedloop_learning.Layer |
setErrors(self, "double *" _errors) | feedforward_closedloop_learning.Layer |
setInput(self, "int" inputIndex, "double" input) | feedforward_closedloop_learning.Layer |
setInputs(self, "double *" _inputs) | feedforward_closedloop_learning.Layer |
setLearningRate(self, "double" _learningRate) | feedforward_closedloop_learning.Layer |
setMaxDetLayer(self, "int" _m) | feedforward_closedloop_learning.Layer |
setMomentum(self, "double" _momentum) | feedforward_closedloop_learning.Layer |
setNormaliseWeights(self, "Layer::WeightNormalisation" _normaliseWeights) | feedforward_closedloop_learning.Layer |
setStep(self, "long" step) | feedforward_closedloop_learning.Layer |
setUseThreads(self, "int" _useThreads) | feedforward_closedloop_learning.Layer |
thisown (defined in feedforward_closedloop_learning.Layer) | feedforward_closedloop_learning.Layer | static
WEIGHT_NORM_LAYER_EUCLEDIAN (defined in feedforward_closedloop_learning.Layer) | feedforward_closedloop_learning.Layer | static
WEIGHT_NORM_LAYER_INFINITY (defined in feedforward_closedloop_learning.Layer) | feedforward_closedloop_learning.Layer | static
WEIGHT_NORM_LAYER_MANHATTAN (defined in feedforward_closedloop_learning.Layer) | feedforward_closedloop_learning.Layer | static
WEIGHT_NORM_NEURON_EUCLEDIAN (defined in feedforward_closedloop_learning.Layer) | feedforward_closedloop_learning.Layer | static
WEIGHT_NORM_NEURON_INFINITY (defined in feedforward_closedloop_learning.Layer) | feedforward_closedloop_learning.Layer | static
WEIGHT_NORM_NEURON_MANHATTAN (defined in feedforward_closedloop_learning.Layer) | feedforward_closedloop_learning.Layer | static
WEIGHT_NORM_NONE (defined in feedforward_closedloop_learning.Layer) | feedforward_closedloop_learning.Layer | static